[HarfBuzz] harfbuzz: Branch 'master' - 2 commits

Behdad Esfahbod behdad at kemper.freedesktop.org
Fri Sep 4 13:41:42 PDT 2009


 src/harfbuzz-shape.h  |    2 +-
 src/harfbuzz-shaper.h |   35 ++++++++++++++++++-----------------
 2 files changed, 19 insertions(+), 18 deletions(-)

New commits:
commit 2c1c5c4d62416489b7593544908a990eef23b8d7
Author: Graham Asher <graham.asher at btinternet.com>
Date:   Wed Sep 2 15:01:33 2009 +0100

    Improved comments for HB_ShaperItem fields.

diff --git a/src/harfbuzz-shape.h b/src/harfbuzz-shape.h
index 4f714a3..e4b5f9a 100644
--- a/src/harfbuzz-shape.h
+++ b/src/harfbuzz-shape.h
@@ -161,7 +161,7 @@ typedef enum {
 /*
  * Buffer for output 
  */
-typedef struct _HB_GlyphBufer HB_GlyphBuffer;
+typedef struct _HB_GlyphBuffer HB_GlyphBuffer;
 struct _HB_GlyphBuffer {
     int glyph_item_size;
     int total_glyphs;



More information about the HarfBuzz mailing list
diff --git a/src/harfbuzz-shaper.h b/src/harfbuzz-shaper.h
index 1577b59..d2357f4 100644
--- a/src/harfbuzz-shaper.h
+++ b/src/harfbuzz-shaper.h
@@ -245,25 +245,26 @@ typedef struct HB_Font_ {
 typedef struct HB_ShaperItem_ HB_ShaperItem;
 
 struct HB_ShaperItem_ {
-    const HB_UChar16 *string;
-    hb_uint32 stringLength;
-    HB_ScriptItem item;
-    HB_Font font;
-    HB_Face face;
-    int shaperFlags; /* HB_ShaperFlags */
-
-    HB_Bool glyphIndicesPresent; /* set to true if the glyph indicies are already setup in the glyphs array */
-    hb_uint32 initialGlyphCount;
-
-    hb_uint32 num_glyphs; /* in: available glyphs out: glyphs used/needed */
-    HB_Glyph *glyphs; /* out parameter */
-    HB_GlyphAttributes *attributes; /* out */
-    HB_Fixed *advances; /* out */
-    HB_FixedPoint *offsets; /* out */
-    unsigned short *log_clusters; /* out */
+    const HB_UChar16 *string;               /* input: the Unicode UTF16 text to be shaped */
+    hb_uint32 stringLength;                 /* input: the length of the input in 16-bit words */
+    HB_ScriptItem item;                     /* input: the current run to be shaped: a run of text all in the same script that is a substring of <string> */
+    HB_Font font;                           /* input: the font: scale, units and function pointers supplying glyph indices and metrics */
+    HB_Face face;                           /* input: the shaper state; current script, access to the OpenType tables , etc. */
+    int shaperFlags;                        /* input (unused) should be set to 0; intended to support flags defined in HB_ShaperFlag */
+    HB_Bool glyphIndicesPresent;            /* input: true if the <glyphs> array contains glyph indices ready to be shaped */
+    hb_uint32 initialGlyphCount;            /* input: if glyphIndicesPresent is true, the number of glyph indices in the <glyphs> array */
+
+    hb_uint32 num_glyphs;                   /* input: capacity of output arrays <glyphs>, <attributes>, <advances>, <offsets>, and <log_clusters>; */
+                                            /* output: required capacity (may be larger than actual capacity) */
+
+    HB_Glyph *glyphs;                       /* output: <num_glyphs> indices of shaped glyphs */
+    HB_GlyphAttributes *attributes;         /* output: <num_glyphs> glyph attributes */
+    HB_Fixed *advances;                     /* output: <num_glyphs> advances */
+    HB_FixedPoint *offsets;                 /* output: <num_glyphs> offsets */
+    unsigned short *log_clusters;           /* output: for each output glyph, the index in the input of the start of its logical cluster */
 
     /* internal */
-    HB_Bool kerning_applied; /* out: kerning applied by shaper */
+    HB_Bool kerning_applied;                /* output: true if kerning was applied by the shaper */
 };
 
 HB_Bool HB_ShapeItem(HB_ShaperItem *item);
commit 75ad92ab672a3300c7232b676435e924598b6948
Author: Behdad Esfahbod <behdad at behdad.org>
Date:   Tue Jun 30 11:26:24 2009 -0400

    Fix typo in unused code
